Learn R Programming

powerMediation (version 0.2.3)

ss.SLR.rho: Sample size for testing slope for simple linear regression based on R2

Description

Calculate sample size for testing slope for simple linear regression based on R2.

Usage

ss.SLR.rho(power, 
           rho2, 
           n.lower = 2.01, 
           n.upper = 1e+30, 
           alpha = 0.05, 
           verbose = TRUE)

Arguments

power
power.
rho2
square of the correlation between the outcome and the predictor.
n.lower
lower bound of the sample size.
n.upper
upper bound o the sample size.
alpha
type I error rate.
verbose
logical. TRUE means printing sample size; FALSE means not printing sample size.

Value

  • nsample size.
  • res.unirootresults of optimization to find the optimal sample size.

Details

The test is for testing the null hypothesis $\lambda=0$ versus the alternative hypothesis $\lambda\neq 0$ for the simple linear regressions: $$y_i=\gamma+\lambda x_i + \epsilon_i, \epsilon_i\sim N(0, \sigma^2_{e})$$

References

Dupont, W.D. and Plummer, W.D.. Power and Sample Size Calculations for Studies Involving Linear Regression. Controlled Clinical Trials. 1998;19:589-601.

See Also

minEffect.SLR, power.SLR, power.SLR.rho, ss.SLR.

Examples

Run this code
ss.SLR.rho(power=0.8, rho2=0.6, alpha = 0.05, verbose = TRUE)

Run the code above in your browser using DataLab