t.cr$\Phi^{-1}(1-\alpha/2)$, where $\Phi$ is the cumulative distribution function of the standard normal distribution.
rhocorrelation between the predictor $x$ and outcome $y$
$=\lambda\sigma_x/\sigma_y$.
Details
The power is for testing the null hypothesis $\lambda=0$
versus the alternative hypothesis $\lambda\neq 0$
for the simple linear regressions:
$$y_i=\gamma+\lambda x_i + \epsilon_i, \epsilon_i\sim N(0, \sigma^2_{e})$$
References
Dupont, W.D. and Plummer, W.D..
Power and Sample Size Calculations for Studies Involving Linear Regression.
Controlled Clinical Trials. 1998;19:589-601.