Learn R Programming

powerMediation (version 0.2.3)

powerLongFull: Power calculation for longitudinal study with 2 time point

Description

Power calculation for testing if mean changes for 2 groups are the same or not for longitudinal study with 2 time point.

Usage

powerLongFull(delta, 
              sigma1, 
              sigma2, 
              n, 
              rho = 0.5, 
              alpha = 0.05)

Arguments

delta
absolute difference of the mean changes between the two groups: $\delta=|\mu_1 - \mu_2|$ where $\mu_1$ is the mean change over time $t$ in group 1, $\mu_2$ is the mean change over time $t$ in group 2.
sigma1
the variance of baseline values within a treatment group
sigma2
the variance of follow-up values within a treatment group
n
sample size per group
rho
correlation coefficient between baseline and follow-up values within a treatment group.
alpha
Type I error rate.

Value

  • power for testing for difference of mean changes.

Details

The power formula is based on Equation 8.31 on page 336 of Rosner (2006). $$power=\Phi\left(-Z_{1-\alpha/2}+\frac{\delta\sqrt{n}}{\sigma_d \sqrt{2}}\right)$$ where $\sigma_d = \sigma_1^2+\sigma_2^2-2\rho\sigma_1\sigma_2$, $\delta=|\mu_1 - \mu_2|$, $\mu_1$ is the mean change over time $t$ in group 1, $\mu_2$ is the mean change over time $t$ in group 2, $\sigma_1^2$ is the variance of baseline values within a treatment group, $\sigma_2^2$ is the variance of follow-up values within a treatment group, $\rho$ is the correlation coefficient between baseline and follow-up values within a treatment group, and $Z_u$ is the u-th percentile of the standard normal distribution.

We wish to test $\mu_1 = \mu_2$.

References

Rosner, B. Fundamentals of Biostatistics. Sixth edition. Thomson Brooks/Cole. 2006.

See Also

ssLong, ssLongFull, powerLong.

Examples

Run this code
# Example 8.34 on page 336 of Rosner (2006)
    # power=0.75
    powerLongFull(delta=5, sigma1=15, sigma2=15, n=75, rho=0.7, alpha=0.05)

Run the code above in your browser using DataLab