testMediation.Sobel(theta.1.hat, lambda.hat, sigma.theta1, sigma.lambda, alpha = 0.05)Test statistic is based on Sobel's (1982) test: $$Z=\frac{\hat{\theta}_1\hat{\lambda}}{\hat{\sigma}_{\theta_1\lambda}} $$ where $\hat{\sigma}_{\theta_1\lambda}$ is the estimated standard deviation of the estimate $\hat{\theta}_1\hat{\lambda}$ using multivariate delta method: $$\sigma_{\theta_1\lambda}=\sqrt{\theta_1^2\sigma_{\lambda}^2+\lambda^2\sigma_{\theta_1}^2}$$ and $\hat{\sigma}_{\theta_1}$ is the estimated standard deviation of the estimate $\hat{\theta}_1$, and $\hat{\sigma}_{\lambda}$ is the estimated standard deviation of the estimate $\hat{\lambda}$.
powerMediation.Sobel,
ssMediation.Sobel
testMediation.Sobel(theta.1.hat=0.1701, lambda.hat=0.1998,
sigma.theta1=0.01, sigma.lambda=0.02, alpha=0.05)
Run the code above in your browser using DataLab